@@ -1,11 +1,11 @@
-#!/usr/bin/env bash
+#!/usr/bin/env sh
 
-set -euo pipefail
-IFS=$'\n\t'
+set -eux
+IFS="$(printf '\n\t')"
 
-SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
+dir=$(cd -- "$(dirname -- "$0")" && pwd)
 
-cd "${SCRIPT_DIR}"
+cd "${dir}"
 
 for build_tags in \
   "" \
